@@ -14,8 +14,7 @@ int main(int argc, char *argv[])
 
 
 
-// my debuging platform win32...
-#ifdef Q_OS_WIN32
+#ifndef Q_WS_MAEMO_5
     w.show();
     w.resize(800,460);
     w.move(0,0);
