@@ -33,53 +33,6 @@ void MainWindow::grabZoomKeys(bool grab)
                  1);
      }
 
-void MainWindow::inet(QListWidgetItem* item){
-inet_source=1;
-
-
-    moo->setCurrentSource(ilist.value(ui.listWidget_2->currentRow()).at(0));
-    moo->play();
-
-
-
-}
-
-void MainWindow::load_inet(){
-
-QFile file("/home/user/tplayer-inet.m3u");
-        if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
-            return;
-
-
-
-QTextStream in(&file);
-
-
-     QString line = in.readLine();
-
-      if (line!="#EXTM3U")return;
-
-int t=0;
-        while (!in.atEnd()) {
-
-           line = in.readLine();
-
-
-           QRegExp rx("^#EXTINF:\\d*,(.*)$") ;
-           rx.indexIn(line);
-           QString title=rx.cap(1);
-           line = in.readLine();
-           ilist.insert(t++,QStringList()<<line<<title<<"Internet radio");
-
-              ui.listWidget_2->addItem(title);
-        }
-
-
-        ui.pushButton_16->setEnabled(true);
-}
-
-
-
 void MainWindow::headphoneEvent(QString what,QString how)
 {
     if (what != "ButtonPressed" || how != "connection")
@@ -122,12 +75,70 @@ void MainWindow::headphoneEvent(QString what,QString how)
 
 }
 
+
 #endif
 
-MainWindow::MainWindow(QWidget *parent)
-    : QMainWindow(parent)
-{
 
+void MainWindow::inet(QListWidgetItem* item){
+inet_source=1;
+
+
+    moo->setCurrentSource(ilist.value(ui.listWidget_2->currentRow()).at(0));
+    moo->play();
+
+
+
+}
+
+void MainWindow::load_inet(){
+
+QFile file(base_path+"tplayer-inet.m3u");
+        if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+            return;
+
+
+
+QTextStream in(&file);
+
+
+     QString line = in.readLine();
+
+      if (line!="#EXTM3U")return;
+
+int t=0;
+        while (!in.atEnd()) {
+
+           line = in.readLine();
+
+
+           QRegExp rx("^#EXTINF:\\d*,(.*)$") ;
+           rx.indexIn(line);
+           QString title=rx.cap(1);
+           line = in.readLine();
+           ilist.insert(t++,QStringList()<<line<<title<<"Internet radio");
+
+              ui.listWidget_2->addItem(title);
+        }
+
+
+        ui.pushButton_16->setEnabled(true);
+}
+
+MainWindow::MainWindow(QWidget *parent)    : QMainWindow(parent)
+{
+#ifdef Q_WS_MAEMO_5
+base_path="/home/user/";
+#else
+#ifdef Q_OS_WIN32
+base_path=qApp->applicationDirPath()+"/";
+#else
+#ifdef Q_WS_S60
+base_path="/data/tplayer/";
+#else
+base_path="/usr/share/tplayer/";
+#endif
+#endif
+#endif
 
 
 
@@ -152,6 +163,8 @@ foreach (Phonon::EffectDescription effectDescription, effectDescriptions)
 
         if ((effectDescription.name() == "KEqualizer") || (effectDescription.name() == "equalizer-10bands"))
         {
+
+          //  ui.pushButton_5->setEnabled(true);
             eqEffect = new Phonon::Effect(effectDescription);
 
         }
@@ -274,7 +287,7 @@ click1();
 int row=-1;
 
      db = QSqlDatabase::addDatabase("QSQLITE");
-     db.setDatabaseName("/home/user/tplayer-list");
+     db.setDatabaseName(base_path+"tplayer-list");
 
      if(db.open()){
      QStringList dbtables = db.tables(QSql::Tables);
@@ -334,7 +347,7 @@ if (on_start==1){
 }
 
 void MainWindow::reload(){
-    QFile file("/home/user/.tplayer-list");
+    QFile file(base_path+".tplayer-list");
          if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
            currentQuery="SELECT * FROM tracks WHERE 1";
        }else{
@@ -344,7 +357,7 @@ void MainWindow::reload(){
        }
 
 
-QFile file2("/home/user/.tplayer-lists");
+QFile file2(base_path+".tplayer-lists");
    if (file2.open(QIODevice::ReadOnly | QIODevice::Text)){
        while(!file2.atEnd()){
            QString data=file2.readLine();
@@ -524,9 +537,26 @@ void MainWindow::toggleEqualizer(bool val)
 
 void MainWindow::load(){
 
-    QFile file("/home/user/.tplayerrc");
+    QFile file(base_path+".tplayerrc");
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
-                return;
+    {
+
+                rotate=0;
+                QFont h("Nokia Sans,18,-1,5,50,0,0,0,0,0");
+
+                h.setPointSize(10);
+                ui.listWidget->setFont(h);
+                namefilter=QString("*.mp3 *.flack *.ogg").split(" ");
+
+    scrobler=new last("","");
+
+    iload=0;
+    on_head_dis=0;
+    on_head_con=0;
+    on_start=0;
+
+              return;
+            }
 
 
             QStringList tyu=QString(file.readAll()).split("\n");
@@ -540,7 +570,7 @@ void MainWindow::load(){
             namefilter=QString(tyu.at(3)).split(" ");
 
 scrobler=new last(tyu.at(4),tyu.at(5));
-scrobler=new last("","");
+
 iload=QString(tyu.at(6)).toLong();
 on_head_dis=QString(tyu.at(7)).toLong();
 on_head_con=QString(tyu.at(8)).toLong();
@@ -872,7 +902,7 @@ box->exec();}
     QString bpath=QString(apath+" - "+list.value(ui.listWidget->currentRow()).at(4)).toLower();
     bpath.replace("/","");
 
-    QString cpath="/home/user/.covers/";
+    QString cpath=base_path+".covers/";
 
     QString dpath=QString(list.value(ui.listWidget->currentRow()).at(1)).toLower();
 
@@ -896,7 +926,7 @@ box->exec();}
 ui.textEdit->setText("");
 ui.textEdit_2->setText("");
 
-    QFile file("/home/user/.bios/"+apath+".html");
+    QFile file(base_path+".bios/"+apath+".html");
     if (!file.exists()){
         if (iload>0){
          QUrl url("http://team16.ru/grab.php?bio="+apath);
@@ -918,7 +948,7 @@ ui.textEdit_2->setText("");
       file.close();
       }
 
-      QFile file2("/home/user/.lyrics/"+apath+"-"+dpath+".html");
+      QFile file2(base_path+".lyrics/"+apath+"-"+dpath+".html");
       if (!file2.exists()){
           if (iload>1){
            QUrl url("http://team16.ru/grab.php?band="+apath+"&lyrics="+dpath);
@@ -985,8 +1015,8 @@ void MainWindow::replyFinished(QNetworkReply*reply){
 
     QDir g;
 
-    g.mkdir("/home/user/.bios");
-    QFile file("/home/user/.bios/"+reply->url().toString().split("=").last()+".html");
+    g.mkdir(base_path+".bios");
+    QFile file(base_path+".bios/"+reply->url().toString().split("=").last()+".html");
         if (!file.open(QIODevice::WriteOnly))  return ;
 
   QString jk;
@@ -1008,8 +1038,8 @@ void MainWindow::replyFinished3(QNetworkReply*reply){
 
     QDir g;
 
-    g.mkdir("/home/user/.lyrics");
-    QFile file("/home/user/.lyrics/"+reply->url().queryItems().at(0).second+"-"+reply->url().queryItems().at(1).second+".html");
+    g.mkdir(base_path+".lyrics");
+    QFile file(base_path+".lyrics/"+reply->url().queryItems().at(0).second+"-"+reply->url().queryItems().at(1).second+".html");
         if (!file.open(QIODevice::WriteOnly))  return ;
 
   QString jk;
@@ -1078,9 +1108,9 @@ fl=reply->url().queryItems().at(0).second;
     else
      fl=reply->url().queryItems().at(0).second+" - "+reply->url().queryItems().at(1).second;
 
-    g.mkdir("/home/user/.covers");
+    g.mkdir(base_path+".covers");
 
-    QFile file("/home/user/.covers/"+fl+".jpg");
+    QFile file(base_path+".covers/"+fl+".jpg");
     if (!file.open(QIODevice::WriteOnly)){
         qDebug(QString::number(file.error()).toAscii());
         return ;}
@@ -1094,7 +1124,7 @@ fl=reply->url().queryItems().at(0).second;
     QString bpath=QString(apath+" - "+list.value(ui.listWidget->currentRow()).at(4)).toLower().replace("/","");
 
 
-    QString cpath="/home/user/.covers/";
+    QString cpath=base_path+".covers/";
     if (QFileInfo(cpath+bpath+".jpg").exists()){
 
         QPixmap *t=new QPixmap(cpath+bpath+".jpg");
@@ -1114,7 +1144,7 @@ void MainWindow::alistload(){
     QAction *t=(QAction *)sender();
 currentQuery=autolist.value(t->text());
 
-QFile file("/home/user/.tplayer-list");
+QFile file(base_path+".tplayer-list");
      if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
          return;
 
@@ -1226,7 +1256,7 @@ void MainWindow::pl_fn_add_dir(){
 
 
     QString d;
-    QString f=QFileDialog::getExistingDirectory(this,"Tplayer","/home/user/MyDocs/.sounds",QFileDialog::ReadOnly);
+    QString f=QFileDialog::getExistingDirectory(this,"Tplayer",base_path+"MyDocs/.sounds",QFileDialog::ReadOnly);
    QApplication::processEvents();
 
     if (!f.isEmpty())
