@@ -3,10 +3,25 @@
 options::options( QWidget *parent) :
     QDialog(parent)
 {
+#ifdef Q_WS_MAEMO_5
+base_path="/home/user/";
+#else
+#ifdef Q_OS_WIN32
+base_path=qApp->applicationDirPath();
+#else
+#ifdef Q_WS_S60
+base_path="/data/tplayer/";
+#else
+base_path="/usr/share/tplayer/";
+#endif
+#endif
+#endif
+
+
     ui.setupUi(this);
 connect(ui.pushButton,SIGNAL(clicked()),this,SLOT(save()));
 
-QFile file("/home/user/.tplayerrc");
+QFile file(base_path+".tplayerrc");
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
             return;
 
@@ -43,7 +58,7 @@ ui.spinBox->setValue(cs);
 }
 
 void options::save(){
-    QFile file("/home/user/.tplayerrc");
+    QFile file(base_path+".tplayerrc");
         if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
             return;
 
